@@ -21,9 +21,9 @@ set -e
 case "$1" in
     configure)
         set +e
-        chown --silent benno.benno /var/log/benno
-        chown --silent benno.benno /srv/benno/archive
-        chown --silent benno.benno /srv/benno/inbox
+        chown --silent benno:benno /var/log/benno
+        chown --silent benno:benno /srv/benno/archive
+        chown --silent benno:benno /srv/benno/inbox
         chmod --silent 2770 /srv/benno/inbox
         set -e
 
